Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewInstallApp ¶
NewInstallApp is used to create a page that collect information from user whether App should be installed
func NewProgress ¶
NewProgress is used to create a page that shows installation progress
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.